P5D_HEADER = [
    'cups',
    'timestamp',
    'season',
    'ai',
    'ae'
]

P1_HEADER = [
    'cups',
    'tipo_medida',
    'timestamp',
    'season',
    'ai',
    'quality_ai',
    'ae',
    'quality_ae',
    'r1',
    'quality_r1',
    'r2',
    'quality_r2',
    'r3',
    'quality_r3',
    'r4',
    'quality_r4',
    'res',
    'quality_res',
    'res2',
    'quality_res2',
    'method',
    'firmeza'
]

P2_HEADER = [
    'cups',
    'tipo_medida',
    'timestamp',
    'season',
    'ai',
    'quality_ai',
    'ae',
    'quality_ae',
    'r1',
    'quality_r1',
    'r2',
    'quality_r2',
    'r3',
    'quality_r3',
    'r4',
    'quality_r4',
    'res',
    'quality_res',
    'res2',
    'quality_res2',
    'method'
]

F1_HEADER = [
    'cups',
    'tipo_medida',
    'timestamp',
    'season',
    'ai',
    'ae',
    'r1',
    'r2',
    'r3',
    'r4',
    'res',
    'res2',
    'method',
    'firmeza'
]

AUTOCONSUMO_HEADER = [
    'cau',
    'miteco',
    'reg_auto_prov',
    'reg_auto_def',
    'tipus_autoconsum',
    'tipus_antiabocament',
    'nom',
    'configuracio_mesura',
    'potencia_nominal',
    'codi_postal',
    'subgrup',
    'emmagatzematge',
    'data_alta',
    'data_baixa'
]

CUPSCAU_HEADER = [
    'cau',
    'cups',
    'tipus_consum',
    'data_alta',
    'data_baixa',
    'comentari'
]

CILCAU_HEADER = [
    'cau',
    'cil',
    'data_alta',
    'data_baixa',
    'comentari'
]

ALMACENACAU_HEADER = [
    'cau',
    'potencia_nominal',
    'energia_emmagatzemable',
    'tecnologia_emmagatzematge',
    'data_alta',
    'data_baixa',
    'comentari'
]

AGRECL_HEADER = [
    'origen',
    'tipus_operacio',
    'distribuidora',
    'comercialitzadora',
    'tensio',
    'tarifa',
    'dh',
    'tipo',
    'provincia',
    'tipus_demanda',
    'data_alta',
    'data_baixa'
]

A5D_HEADER = [
    'cups',
    'timestamp',
    'season',
    'ai',
    'ae',
    'r1',
    'r2',
    'r3',
    'r4',
    'method',
    'firmeza',
    'factura'
]

B5D_HEADER = [
    'cups',
    'timestamp',
    'season',
    'ai',
    'ae',
    'r1',
    'r2',
    'r3',
    'r4',
    'method',
    'firmeza',
    'factura'
]

PMEST_HEADER = [
    'pm',
    'tipo_medida',
    'timestamp',
    'season',
    'method',
    'ai',
    'ae',
    'r1',
    'r2',
    'r3',
    'r4'
]